@@ -110,6 +110,10 @@ def test_serialize_workflow_with_filepath():
             "module": ["tests", "workflows", "basic_code_execution_node", "workflow"],
             "name": "SimpleCodeExecutionNode",
         },
+        "trigger": {
+            "id": "e02a2701-22c0-4533-8b00-175998e7350a",
+            "merge_behavior": "AWAIT_ANY",
+        },
         "ports": [{"id": "832f81ec-427b-42a8-825c-e62c43c1f961", "name": "default", "type": "DEFAULT"}],
     }
     assert not DeepDiff(
@@ -342,6 +346,10 @@ def test_serialize_workflow_with_code():
             "name": "SimpleCodeExecutionNode",
             "module": ["tests", "workflows", "basic_code_execution_node", "workflow_with_code"],
         },
+        "trigger": {
+            "id": "e02a2701-22c0-4533-8b00-175998e7350a",
+            "merge_behavior": "AWAIT_ANY",
+        },
         "ports": [{"id": "832f81ec-427b-42a8-825c-e62c43c1f961", "name": "default", "type": "DEFAULT"}],
     }
     assert not DeepDiff(
@@ -591,7 +599,7 @@ def test_serialize_workflow__try_wrapped():
         "adornments": [
             {
                 "id": "3344083c-a32c-4a32-920b-0fb5093448fa",
-                "label": "TryNode",
+                "label": "Try Node",
                 "base": {"name": "TryNode", "module": ["vellum", "workflows", "nodes", "core", "try_node", "node"]},
                 "attributes": [
                     {
@@ -602,6 +610,10 @@ def test_serialize_workflow__try_wrapped():
                 ],
             }
         ],
+        "trigger": {
+            "id": "e02a2701-22c0-4533-8b00-175998e7350a",
+            "merge_behavior": "AWAIT_ANY",
+        },
         "ports": [{"id": "832f81ec-427b-42a8-825c-e62c43c1f961", "name": "default", "type": "DEFAULT"}],
     }
 
