@@ -219,7 +219,7 @@ def test_serialize_workflow():
                         "type": "DICTIONARY_REFERENCE",
                         "entries": [
                             {
-                                "id": "0bfa70a2-164f-460c-9e9a-4d62221eadf4",
+                                "id": "6eb6687c-f894-4398-8e62-7dc89e96a0a4",
                                 "key": "noun",
                                 "value": {
                                     "type": "WORKFLOW_INPUT",
@@ -521,37 +521,37 @@ def test_serialize_workflow_with_nested_descriptor_blocks():
         {
             "entries": [
                 {
-                    "id": "24a203be-3cba-4b20-bc84-9993a476c120",
+                    "id": "4e61fbcf-13b3-4d5f-b5fb-2bf919a92045",
                     "key": "block_type",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "CHAT_MESSAGE"}},
                 },
                 {
-                    "id": "c06269e6-f74c-4860-8fa5-22dcbdc89399",
+                    "id": "79dd757e-46db-4c36-9ffc-ddb763d14f27",
                     "key": "state",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "JSON", "value": None}},
                 },
                 {
-                    "id": "dd9c0d43-b931-4dc8-8b3a-a7507ddff0c1",
+                    "id": "2f8164e8-5495-4b9c-8268-d75618cd0842",
                     "key": "cache_config",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "JSON", "value": None}},
                 },
                 {
-                    "id": "bef22f2b-0b6e-4910-88cc-6df736d2e20e",
+                    "id": "0e8dc132-de9a-40dc-9845-336bc957df5a",
                     "key": "chat_role",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "SYSTEM"}},
                 },
                 {
-                    "id": "c0beec30-f85e-4a78-a3fb-baee54a692f8",
+                    "id": "755a45d2-2420-4414-b318-5790880f84ec",
                     "key": "chat_source",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "JSON", "value": None}},
                 },
                 {
-                    "id": "f601f4f2-62fe-4697-9fe0-99ca8aa64500",
+                    "id": "3a563cdb-d130-497f-bac6-c324a4349a3c",
                     "key": "chat_message_unterminated",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "JSON", "value": None}},
                 },
                 {
-                    "id": "ad550008-64e3-44a3-a32a-84ec226db31c",
+                    "id": "2d0c084e-c54f-48f5-9444-a17f8aeb8f76",
                     "key": "blocks",
                     "value": {
                         "items": [
