@@ -706,12 +706,12 @@ def test_serialize_workflow__dict_reference():
         "type": "DICTIONARY_REFERENCE",
         "entries": [
             {
-                "id": "b528ce26-68ee-42ba-828d-199441810685",
+                "id": "7689f0df-e0bc-4e53-a63f-dbee027f58b9",
                 "key": "key1",
                 "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "constant1"}},
             },
             {
-                "id": "a7acccfe-2f80-42ee-a307-c1eb0b137c2b",
+                "id": "89e01555-b0b5-42d5-a0a7-bce72716cf65",
                 "key": "key2",
                 "value": {
                     "type": "NODE_OUTPUT",
@@ -720,12 +720,12 @@ def test_serialize_workflow__dict_reference():
                 },
             },
             {
-                "id": "8f41013e-7a9f-4659-ac17-c25c6ec6fe99",
+                "id": "2dc84109-b85c-4732-aa60-8c10a1a377d2",
                 "key": "key3",
                 "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "constant2"}},
             },
             {
-                "id": "609e84e8-573a-44ea-b3aa-82c3f3cc2c36",
+                "id": "d1b3ce75-1b1e-45e3-b798-beafe6c4826f",
                 "key": "key4",
                 "value": {
                     "type": "NODE_OUTPUT",
@@ -745,18 +745,18 @@ def test_serialize_workflow__dict_reference():
         "type": "DICTIONARY_REFERENCE",
         "entries": [
             {
-                "id": "02abe9d0-bf93-4eea-b34a-902dae7c2b90",
+                "id": "7689f0df-e0bc-4e53-a63f-dbee027f58b9",
                 "key": "key1",
                 "value": {
                     "type": "DICTIONARY_REFERENCE",
                     "entries": [
                         {
-                            "id": "b528ce26-68ee-42ba-828d-199441810685",
+                            "id": "7689f0df-e0bc-4e53-a63f-dbee027f58b9",
                             "key": "key1",
                             "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "constant1"}},
                         },
                         {
-                            "id": "a7acccfe-2f80-42ee-a307-c1eb0b137c2b",
+                            "id": "89e01555-b0b5-42d5-a0a7-bce72716cf65",
                             "key": "key2",
                             "value": {
                                 "type": "NODE_OUTPUT",
@@ -768,18 +768,18 @@ def test_serialize_workflow__dict_reference():
                 },
             },
             {
-                "id": "c8640477-13cc-412e-82cc-35cbe9e78ff2",
+                "id": "89e01555-b0b5-42d5-a0a7-bce72716cf65",
                 "key": "key2",
                 "value": {
                     "type": "DICTIONARY_REFERENCE",
                     "entries": [
                         {
-                            "id": "86709f21-a811-4351-993e-a8e9f1c7774f",
+                            "id": "7689f0df-e0bc-4e53-a63f-dbee027f58b9",
                             "key": "key1",
                             "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "constant2"}},
                         },
                         {
-                            "id": "a7acccfe-2f80-42ee-a307-c1eb0b137c2b",
+                            "id": "89e01555-b0b5-42d5-a0a7-bce72716cf65",
                             "key": "key2",
                             "value": {
                                 "type": "NODE_OUTPUT",
