@@ -9,6 +9,7 @@ from vellum.workflows import BaseWorkflow
 from vellum.workflows.nodes import BaseNode
 from vellum.workflows.state.context import WorkflowContext
 from vellum.workflows.utils.uuids import generate_workflow_deployment_prefix
+from vellum.workflows.utils.zip import zip_file_map
 from vellum_ee.workflows.display.workflows.base_workflow_display import BaseWorkflowDisplay
 from vellum_ee.workflows.server.virtual_file_loader import VirtualFileFinder
 
@@ -661,3 +662,117 @@ __all__ = ["TestNode"]
 
     # AND the method should return a workflow (not None) - this will pass once implemented
     assert event.name == "workflow.execution.fulfilled"
+
+
+def test_resolve_workflow_deployment__uses_pull_api_with_inputs_deployment_name(vellum_client):
+    """
+    Test that resolve_workflow_deployment uses the pull API to fetch subworkflow files
+    when the deployment name comes from Inputs.deployment_name.
+    """
+    # GIVEN a deployment name and release tag
+    deployment_name = "test_deployment"
+    release_tag = "LATEST"
+
+    test_node_code = """
+from vellum.workflows.nodes.bases.base import BaseNode
+from vellum.workflows.outputs import BaseOutputs
+
+class TestNode(BaseNode):
+    template = "Hello"
+
+    class Outputs(BaseOutputs):
+        result: str
+
+    def run(self):
+        return self.Outputs(result="Hello, {template}")
+"""
+
+    mock_workflow_code = """
+from vellum.workflows import BaseWorkflow
+from .nodes.test_node import TestNode
+
+class ResolvedWorkflow(BaseWorkflow):
+    graph = TestNode
+"""
+
+    inputs_code = """
+from vellum.workflows.inputs import BaseInputs
+
+class Inputs(BaseInputs):
+    deployment_name: str
+"""
+
+    parent_workflow_code = """
+from vellum.workflows import BaseWorkflow
+from .inputs import Inputs
+from .nodes.subworkflow_deployment_node import TestSubworkflowDeploymentNode
+from vellum.workflows.state import BaseState
+
+class ParentWorkflow(BaseWorkflow[Inputs, BaseState]):
+    graph = TestSubworkflowDeploymentNode
+"""
+
+    parent_node_code = """
+from vellum.workflows.nodes import SubworkflowDeploymentNode
+from vellum.workflows.outputs import BaseOutputs
+from ..inputs import Inputs
+
+class TestSubworkflowDeploymentNode(SubworkflowDeploymentNode):
+    deployment = Inputs.deployment_name
+
+    class Outputs(BaseOutputs):
+        result: str
+
+    subworkflow_inputs = {"message": "test"}
+"""
+
+    subworkflow_files = {
+        "__init__.py": "",
+        "workflow.py": mock_workflow_code,
+        "nodes/__init__.py": """
+from .test_node import TestNode
+
+__all__ = ["TestNode"]
+""",
+        "nodes/test_node.py": test_node_code,
+    }
+
+    parent_files = {
+        "__init__.py": "",
+        "inputs.py": inputs_code,
+        "workflow.py": parent_workflow_code,
+        "nodes/__init__.py": """
+from .subworkflow_deployment_node import TestSubworkflowDeploymentNode
+
+__all__ = ["TestSubworkflowDeploymentNode"]
+""",
+        "nodes/subworkflow_deployment_node.py": parent_node_code,
+    }
+
+    namespace = str(uuid4())
+
+    # AND the virtual file loader is registered for the parent workflow
+    finder = VirtualFileFinder(parent_files, namespace)
+    sys.meta_path.append(finder)
+
+    vellum_client.workflows.pull.return_value = iter([zip_file_map(subworkflow_files)])
+
+    # WHEN we execute the root workflow with the mocked client
+    Workflow = BaseWorkflow.load_from_module(namespace)
+    Inputs = Workflow.get_inputs_class()
+
+    workflow = Workflow(context=WorkflowContext(namespace=namespace, generated_files=parent_files))
+    final_event = workflow.run(inputs=Inputs(deployment_name=deployment_name))
+
+    # THEN the method should return a workflow (not None) - this will pass once implemented
+    assert final_event.name == "workflow.execution.fulfilled", final_event
+
+    # AND the pull API should have been called with the correct deployment name, release tag, and version
+    args, kwargs = vellum_client.workflows.pull.call_args
+    assert args[0] == deployment_name
+    assert kwargs["release_tag"] == release_tag
+    assert kwargs["version"].startswith(">=")
+    assert ".0.0,<=" in kwargs["version"]
+
+    # AND the X-Vellum-Always-Success header should be included for graceful error handling
+    assert kwargs["request_options"]["additional_headers"]["X-Vellum-Always-Success"] == "true"
