@@ -126,7 +126,10 @@ class VellumEmitter(BaseWorkflowEmitter):
             return
 
         client = self._context.vellum_client
-        request_options = RequestOptions(timeout_in_seconds=self._timeout, max_retries=self._max_retries)
+        if self._timeout is not None:
+            request_options = RequestOptions(timeout_in_seconds=int(self._timeout), max_retries=self._max_retries)
+        else:
+            request_options = RequestOptions(max_retries=self._max_retries)
 
         client.events.create(
             # The API accepts a ClientWorkflowEvent but our SDK emits an SDKWorkflowEvent. These shapes are
@@ -135,3 +138,13 @@ class VellumEmitter(BaseWorkflowEmitter):
             request=events,  # type: ignore[arg-type]
             request_options=request_options,
         )
+
+    def join(self) -> None:
+        """
+        Wait for any background threads or timers used by this emitter to complete.
+        This ensures all pending work is finished before the workflow terminates.
+        """
+        self._flush_events()
+
+        if self._debounce_timer and self._debounce_timer.is_alive():
+            self._debounce_timer.join()
