@@ -86,23 +86,23 @@ def test_parse_type_from_str_list_of_models():
             List[str],
             NodeException,
             WorkflowErrorCode.INVALID_OUTPUTS,
-            "Invalid JSON Array format for result_as_str",
+            "Invalid JSON format: expected a valid JSON array",
         ),
         (
             "{invalid json}",
             Person,
             NodeException,
             WorkflowErrorCode.INVALID_OUTPUTS,
-            "Invalid JSON format for result_as_str",
+            "Invalid JSON format: unable to parse the provided data",
         ),
         (
             "{invalid json}",
             Json,
             NodeException,
             WorkflowErrorCode.INVALID_OUTPUTS,
-            "Invalid JSON format for result_as_str",
+            "Invalid JSON format: unable to parse the provided data",
         ),
-        ('{"name": "Alice"}', List[str], ValueError, None, "Expected a list of items for result_as_str, received dict"),
+        ('{"name": "Alice"}', List[str], ValueError, None, "Expected a list of items, but received dict"),
         ("data", object, ValueError, None, "Unsupported output type: <class 'object'>"),
     ],
     ids=[
