@@ -1,19 +1,6 @@
 import dataclasses
 import inspect
-from typing import (
-    TYPE_CHECKING,
-    Annotated,
-    Any,
-    Callable,
-    Dict,
-    List,
-    Literal,
-    Optional,
-    Type,
-    Union,
-    get_args,
-    get_origin,
-)
+from typing import TYPE_CHECKING, Annotated, Any, Callable, List, Literal, Optional, Type, Union, get_args, get_origin
 
 from pydantic import BaseModel
 from pydantic_core import PydanticUndefined
@@ -21,14 +8,22 @@ from pydash import snake_case
 
 from vellum import Vellum
 from vellum.client.types.function_definition import FunctionDefinition
+from vellum.workflows.integrations.composio_service import ComposioService
 from vellum.workflows.integrations.mcp_service import MCPService
-from vellum.workflows.types.definition import MCPServer, MCPToolDefinition
+from vellum.workflows.integrations.vellum_integration_service import VellumIntegrationService
+from vellum.workflows.types.definition import (
+    ComposioToolDefinition,
+    DeploymentDefinition,
+    MCPServer,
+    MCPToolDefinition,
+    VellumIntegrationToolDefinition,
+)
 from vellum.workflows.utils.vellum_variables import vellum_variable_type_to_openapi_type
 
 if TYPE_CHECKING:
     from vellum.workflows.workflows.base import BaseWorkflow
 
-type_map = {
+type_map: dict[Any, str] = {
     str: "string",
     int: "integer",
     float: "number",
@@ -38,8 +33,13 @@ type_map = {
     None: "null",
     type(None): "null",
     inspect._empty: "null",
+    "None": "null",
 }
 
+for k, v in list(type_map.items()):
+    if isinstance(k, type):
+        type_map[k.__name__] = v
+
 
 def compile_annotation(annotation: Optional[Any], defs: dict[str, Any]) -> dict:
     if annotation is None:
@@ -96,22 +96,21 @@ def compile_annotation(annotation: Optional[Any], defs: dict[str, Any]) -> dict:
             defs[annotation.__name__] = {"type": "object", "properties": properties, "required": required}
         return {"$ref": f"#/$defs/{annotation.__name__}"}
 
-    if issubclass(annotation, BaseModel):
+    if inspect.isclass(annotation) and issubclass(annotation, BaseModel):
         if annotation.__name__ not in defs:
             properties = {}
             required = []
-            for field_name, field in annotation.model_fields.items():
-                # Mypy is incorrect here, the `annotation` attribute is defined on `FieldInfo`
-                field_annotation = field.annotation  # type: ignore[attr-defined]
-                properties[field_name] = compile_annotation(field_annotation, defs)
+            for field_name, field_info in annotation.model_fields.items():
+                # field_info is a FieldInfo object which has an annotation attribute
+                properties[field_name] = compile_annotation(field_info.annotation, defs)
 
-                if hasattr(field, "description") and field.description is not None:
-                    properties[field_name]["description"] = field.description  # type: ignore[attr-defined]
+                if field_info.description is not None:
+                    properties[field_name]["description"] = field_info.description
 
-                if field.default is PydanticUndefined:
+                if field_info.default is PydanticUndefined:
                     required.append(field_name)
                 else:
-                    properties[field_name]["default"] = _compile_default_value(field.default)
+                    properties[field_name]["default"] = _compile_default_value(field_info.default)
             defs[annotation.__name__] = {"type": "object", "properties": properties, "required": required}
 
         return {"$ref": f"#/$defs/{annotation.__name__}"}
@@ -238,25 +237,21 @@ def compile_inline_workflow_function_definition(workflow_class: Type["BaseWorkfl
 
 
 def compile_workflow_deployment_function_definition(
-    deployment_config: Dict[str, str],
+    deployment_definition: DeploymentDefinition,
     vellum_client: Vellum,
 ) -> FunctionDefinition:
     """
     Converts a deployment workflow config into our Vellum-native FunctionDefinition type.
 
     Args:
-        deployment_config: Dict with 'deployment' and 'release_tag' keys
+        deployment_definition: DeploymentDefinition instance
         vellum_client: Vellum client instance
     """
-    deployment = deployment_config["deployment"]
-    release_tag = deployment_config["release_tag"]
+    release_info = deployment_definition.get_release_info(vellum_client)
 
-    workflow_deployment_release = vellum_client.workflow_deployments.retrieve_workflow_deployment_release(
-        deployment, release_tag
-    )
-
-    input_variables = workflow_deployment_release.workflow_version.input_variables
-    description = workflow_deployment_release.description
+    name = release_info["name"]
+    description = release_info["description"]
+    input_variables = release_info["input_variables"]
 
     properties = {}
     required = []
@@ -270,7 +265,7 @@ def compile_workflow_deployment_function_definition(
     parameters = {"type": "object", "properties": properties, "required": required}
 
     return FunctionDefinition(
-        name=deployment.replace("-", ""),
+        name=name.replace("-", ""),
         description=description,
         parameters=parameters,
     )
@@ -300,6 +295,61 @@ def compile_mcp_tool_definition(server_def: MCPServer) -> List[MCPToolDefinition
         return []
 
 
+def compile_composio_tool_definition(tool_def: ComposioToolDefinition) -> FunctionDefinition:
+    """Hydrate a ComposioToolDefinition with detailed information from the Composio API.
+
+    Args:
+        tool_def: The basic ComposioToolDefinition to enhance
+
+    Returns:
+        FunctionDefinition with detailed parameters and description
+    """
+    try:
+        composio_service = ComposioService()
+        tool_details = composio_service.get_tool_by_slug(tool_def.action)
+
+        # Create a FunctionDefinition directly with proper field extraction
+        return FunctionDefinition(
+            name=tool_def.name,
+            description=tool_details.get("description", tool_def.description),
+            parameters=tool_details.get("input_parameters", {}),
+        )
+    except Exception:
+        # If hydration fails (including no API key), return basic function definition
+        return FunctionDefinition(
+            name=tool_def.name,
+            description=tool_def.description,
+            parameters={},
+        )
+
+
+def compile_vellum_integration_tool_definition(tool_def: VellumIntegrationToolDefinition) -> FunctionDefinition:
+    """Compile a VellumIntegrationToolDefinition into a FunctionDefinition.
+
+    Args:
+        tool_def: The VellumIntegrationToolDefinition to compile
+
+    Returns:
+        FunctionDefinition with tool parameters and description
+    """
+    try:
+        service = VellumIntegrationService()
+        tool_details = service.get_tool_definition(
+            integration=tool_def.integration,
+            provider=tool_def.provider.value,
+            tool_name=tool_def.name,
+        )
+
+        return FunctionDefinition(
+            name=tool_def.name,
+            description=tool_details.description,
+            parameters=tool_details.parameters or {},
+        )
+    except Exception:
+        # Fallback for service failures
+        return FunctionDefinition(name=tool_def.name, description=tool_def.description, parameters={})
+
+
 def use_tool_inputs(**inputs):
     """
     Decorator to specify which parameters of a tool function should be provided
