@@ -2,15 +2,21 @@ import os
 from typing import List, Optional
 
 from vellum import Vellum, VellumEnvironment
+from vellum.client.types.api_version_enum import ApiVersionEnum
 
 
-def create_vellum_client(api_key: Optional[str] = None, api_url: Optional[str] = None) -> Vellum:
+def create_vellum_client(
+    api_key: Optional[str] = None,
+    api_url: Optional[str] = None,
+    api_version: Optional[ApiVersionEnum] = None,
+) -> Vellum:
     if api_key is None:
         api_key = os.getenv("VELLUM_API_KEY", default="")
 
     return Vellum(
         api_key=api_key,
         environment=create_vellum_environment(api_url),
+        api_version=api_version,
     )
 
 
