@@ -31,6 +31,7 @@ from vellum.workflows.edges import Edge
 from vellum.workflows.emitters.base import BaseWorkflowEmitter
 from vellum.workflows.errors import WorkflowError, WorkflowErrorCode
 from vellum.workflows.events.node import (
+    NodeEvent,
     NodeExecutionFulfilledBody,
     NodeExecutionFulfilledEvent,
     NodeExecutionInitiatedBody,
@@ -252,6 +253,7 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         self.resolvers = resolvers or (self.resolvers if hasattr(self, "resolvers") else [])
         self._store = store or Store()
         self._execution_context = self._context.execution_context
+        self._current_runner: Optional[WorkflowRunner] = None
 
         # Register context with all emitters
         for emitter in self.emitters:
@@ -412,7 +414,7 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
             subworkflows or nodes that utilizes threads.
         """
 
-        events = WorkflowRunner(
+        runner = WorkflowRunner(
             self,
             inputs=inputs,
             state=state,
@@ -423,7 +425,9 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
             node_output_mocks=node_output_mocks,
             max_concurrency=max_concurrency,
             init_execution_context=self._execution_context,
-        ).stream()
+        )
+        self._current_runner = runner
+        events = runner.stream()
         first_event: Optional[Union[WorkflowExecutionInitiatedEvent, WorkflowExecutionResumedEvent]] = None
         last_event = None
         for event in events:
@@ -531,7 +535,7 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         """
 
         should_yield = event_filter or workflow_event_filter
-        runner_stream = WorkflowRunner(
+        runner = WorkflowRunner(
             self,
             inputs=inputs,
             state=state,
@@ -542,7 +546,9 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
             node_output_mocks=node_output_mocks,
             max_concurrency=max_concurrency,
             init_execution_context=self._execution_context,
-        ).stream()
+        )
+        self._current_runner = runner
+        runner_stream = runner.stream()
 
         def _generate_filtered_events() -> Generator[BaseWorkflow.WorkflowEvent, None, None]:
             for event in runner_stream:
@@ -559,6 +565,15 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         # https://app.shortcut.com/vellum/story/4327
         pass
 
+    def run_node(
+        self, node: Type[BaseNode], *, inputs: Optional[Dict[str, Any]] = None
+    ) -> Generator[NodeEvent, None, None]:
+        runner = WorkflowRunner(self)
+        span_id = uuid4()
+        node_instance = node(state=self.get_default_state(), context=self._context, inputs=inputs)
+
+        return runner.run_node(node=node_instance, span_id=span_id)
+
     @classmethod
     @lru_cache
     def _get_parameterized_classes(
@@ -687,6 +702,17 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
             raise ValueError(f"Multiple workflows found in {module_path}")
         return workflows[0]
 
+    def join(self) -> None:
+        """
+        Wait for all emitters and runner to complete their background work.
+        This ensures all pending events are processed before the workflow terminates.
+        """
+        if self._current_runner:
+            self._current_runner.join()
+
+        for emitter in self.emitters:
+            emitter.join()
+
 
 WorkflowExecutionInitiatedBody.model_rebuild()
 WorkflowExecutionFulfilledBody.model_rebuild()
